@@ -1,6 +1,6 @@
+import importlib.util
 import os.path
 import subprocess
-import importlib.util
 import sys
 
 
@@ -14,7 +14,12 @@ def _get_py_hook_type(hook_type: str) -> None | str:
 
 
 def _execute_shell_hook(hook_type: str):
-    subprocess.run(['bash', f'./.barb/{hook_type}'])
+    try:
+        subprocess.run(['bash', f'./.barb/{hook_type}'])
+    except Exception as e:
+        print(f'An exception occurred when attempting to execute the git hook {hook_type}.')
+        print(e)
+        sys.exit(1)
 
 
 def _execute_python_hook(hook_type: str):
@@ -43,6 +48,7 @@ def run_hook(hook: str):
     if not hook_type:
         return
 
+    print(f'[running hook {hook}]')
     if hook_type == 'SHELL':
         _execute_shell_hook(hook)
     elif hook_type == 'PYTHON':
